<?php

class pluginBuyMeACoffee extends Plugin
{
    public function init()
    {
        $this->dbFields = [
            'buymeacoffee_url' => '',
            'enable_sidebar' => 'yes',
            'enable_pages' => 'yes',
            'custom_text' => '<b>Enjoying my writings? Consider purchasing me a coffee or two! ☕</b>',
            'button_instead' => 'no',
            'button_color' => 'primary',
        ];
    }

    public function form()
    {
        global $L;
        $fields = [
            'buymeacoffee_url' => [
                'type' => 'text',
                'label' => $L->get('Buy Me a Coffee URL'),
                'placeholder' => 'https://www.buymeacoffee.com',
            ],
            'enable_sidebar' => [
                'type' => 'select',
                'label' => $L->get('Show Sidebar Image'),
                'options' => ['yes' => $L->get('Yes'), 'no' => $L->get('No')],
            ],
            'enable_pages' => [
                'type' => 'select',
                'label' => $L->get('Show Text on Pages'),
                'options' => ['yes' => $L->get('Yes'), 'no' => $L->get('No')],
            ],
            'custom_text' => [
                'type' => 'textarea',
                'label' => $L->get('Text Shown at Bottom <small>(HTML supported)</small>'),
            ],
            'button_instead' => [
                'type' => 'select',
                'label' => $L->get('Button Instead of Image'),
                'options' => ['yes' => $L->get('Yes'), 'no' => $L->get('No')],
            ],
            'button_color' => [
                'type' => 'select',
                'label' => $L->get('Button Color'),
                'options' => [
                    'primary' => $L->get('Primary'),
                    'secondary' => $L->get('Secondary'),
                    'success' => $L->get('Green'),
                    'danger' => $L->get('Red'),
                    'warning' => $L->get('Yellow'),
                    'info' => $L->get('Blue'),
                    'light' => $L->get('Light'),
                    'dark' => $L->get('Dark'),
                    'link' => $L->get('Link'),
                ],
            ],
        ];

        return $this->generateFormHtml($fields);
    }

    private function generateFormHtml($fields)
    {
        $html = '';
        foreach ($fields as $name => $field) {
            $value = $this->getValue($name);
            switch ($field['type']) {
                case 'text':
                    $html .= "<div><label for='{$name}'>{$field['label']}</label>";
                    $html .= "<input type='text' name='{$name}' id='{$name}' value='{$value}' placeholder='{$field['placeholder']}'></div>";
                    break;
                case 'textarea':
                    $html .= "<div><label for='{$name}'>{$field['label']}</label>";
                    $html .= "<textarea name='{$name}' id='{$name}' rows='5'>{$value}</textarea></div>";
                    break;
                case 'select':
                    $html .= "<div><label>{$field['label']}</label><select name='{$name}'>";
                    foreach ($field['options'] as $optionValue => $optionLabel) {
                        $selected = $value === $optionValue ? 'selected' : '';
                        $html .= "<option value='{$optionValue}' {$selected}>{$optionLabel}</option>";
                    }
                    $html .= "</select></div>";
                    break;
            }
            $html .= '<hr>';
        }
        return rtrim($html, '<hr>');
    }

    public function siteSidebar()
    {
        if ($this->getValue('enable_sidebar') === 'yes' && ($buymeacoffeeURL = $this->getValue('buymeacoffee_url'))) {
            return sprintf(
                '<div class="plugin plugin-buymeacoffee-sidebar"><a href="%s" target="_blank"><img src="%sbuy-me-a-coffee/img/bmc-button.png" alt="Buy Me a Coffee"></a></div>',
                $buymeacoffeeURL, HTML_PATH_PLUGINS
            );
        }
        return '';
    }

    public function pageEnd()
    {
        global $WHERE_AM_I, $page;

        if ($WHERE_AM_I === 'page' && $this->getValue('enable_pages') === 'yes') {
            $buymeacoffeeURL = $this->getValue('buymeacoffee_url');
            if (empty($buymeacoffeeURL)) return;

            $customText = $page->custom('custom_text') ?: $this->getValue('custom_text');
            $buttonHtml = $this->generateButtonHtml($buymeacoffeeURL, $this->getValue('button_instead'), $this->getValue('button_color'));

            echo '<hr><div class="row">';
            echo '<div class="col-md-8" style="display: flex; justify-content: center; align-items: center;">' . htmlspecialchars_decode(stripslashes($customText)) . '</div>';
            echo "<div class='col-md-4' style='display: flex; justify-content: center; align-items: center;'>{$buttonHtml}</div>";
            echo '</div>';
        }
    }

    private function generateButtonHtml($url, $showButtonInstead, $buttonColor)
    {
        if ($showButtonInstead === 'yes') {
            return "<a href='{$url}' target='_blank' class='btn btn-{$buttonColor}'>Buy Me A Coffee</a>";
        } else {
            return "<a href='{$url}' target='_blank'><img src='" . HTML_PATH_PLUGINS . "buy-me-a-coffee/img/bmc-button.png' alt='Buy Me a Coffee'></a>";
        }
    }
}